
package com.adakoda.android.graphanimationsample;

import android.animation.ObjectAnimator;
import android.app.Activity;
import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.LinearGradient;
import android.graphics.Paint;
import android.graphics.Rect;
import android.graphics.Shader.TileMode;
import android.os.Bundle;
import android.view.MotionEvent;
import android.view.View;

//
// 「独自のオブジェクトをアニメーションさせる」サンプル
//
// 開発環境
// - Eclipse 3.7.2
// - Android SDK Tools Rev.20.0.1 (Android 3.0 (API Level 11) / Android 4.0 (API Level 14))
// - Android SDK Platform-tools Rev.13
// - ADT 20.0.2
//
// 動作確認済デバイス
// - Galaxy Nexus Android 4.0
//
public class GraphAnimationSampleActivity extends Activity {

    // グラフビュークラス
    public class GraphView extends View {

        public GraphView(Context context) {
            super(context);
        }

        // グラフのデータ
        private int[] mData;

        // グラフのデータを取得
        public int[] getData() {
            return mData;
        }

        // グラフのデータを設定
        public void setData(int[] data) {
            mData = data;
            invalidate();
        }

        // バーを描画する
        @Override
        protected void onDraw(Canvas canvas) {
            super.onDraw(canvas);
            if (mData != null) {
                for (int i = 0; i < mData.length; i++) {
                    Rect rect = new Rect(i * 10, 100 - mData[i], (i + 1) * 10, 100);
                    // グラフのバーを塗りつぶすためのグラデーションを作成
                    LinearGradient gr = new LinearGradient(
                            rect.left, rect.top, rect.right, rect.bottom,
                            Color.CYAN, Color.BLACK, TileMode.CLAMP);
                    Paint paint = new Paint();
                    paint.setShader(gr);
                    // グラフのバーを塗りつぶして描画
                    canvas.drawRect(rect, paint);
                }
            }
        }

    }

    // グラフビュー
    private GraphView mGraphView;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        // グラフビューを作成し、アクティビティのビューに設定
        mGraphView = new GraphView(this);
        setContentView(mGraphView);
        // 初期データ（右肩上がりのデータ）を設定
        int[] data = {
                0, 10, 20, 30, 40, 50, 60, 70, 80, 90, 100
        };
        mGraphView.setData(data);
    }

    @Override
    public boolean onTouchEvent(MotionEvent event) {
        if (event.getAction() == MotionEvent.ACTION_DOWN) {
            // 現在設定されているデータを取得
            int[] data = mGraphView.getData();
            // 新しいデータはグラフを反転させたデータとする
            int[] newData = new int[data.length];
            for (int i = 0; i < data.length; i++) {
                newData[i] = data[data.length - i - 1];
            }

            // グラフに新しいデータを設定
            // mGraphView.setData(newData);

            ObjectAnimator animator = ObjectAnimator.ofObject(
                    mGraphView, "data", new IntArrayEvaluator(), newData);
            animator.setDuration(1000);
            animator.start();
            return true;
        } else {
            return super.onTouchEvent(event);
        }
    }

}
